@@ -171,6 +171,9 @@ class RpcExchangerClient:
                 msg = json_content["msg"]
                 chat = int(raw_message["channel"][9:])
                 log.debug(f"{username=} {msg=} {chat=}")
+                if username == "system":
+                    if "kick" in msg:
+                        await self.chat_list_somebody_joined()
             except Exception as e:
                 log.debug(e, exc_info=True)
                 raw_message = None
@@ -235,6 +238,8 @@ class RpcExchangerClient:
 
     async def chat_kick(self, chat_id: int, kicked_user_id: int) -> bool:
         self.check_authorized()
+        if self._uid == kicked_user_id:
+            return False
         return await self._rpc.chat.kick(chat_id=chat_id, user_id=self._uid, kicked_user_id=kicked_user_id)
 
     async def chat_rename(self, chat_id: int, new_name: str) -> bool:
